%global _with_test 0

Summary:        High-performance memory object caching system
Name:           memcached
Version:        1.4.25
Release:        %mkrel 1
License:        BSD
Group:          System/Servers
URL:            http://memcached.org/
Source0:        http://memcached.googlecode.com/files/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        memcached.sysconfig
Source3:        memcached.logrotate
Source4:        memcached@.service
Source5:        memcached.target
patch0:         memcached-CVE-2016-8704_8705_8706.patch
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:       cyrus-sasl sasl-plug-plain sasl-plug-crammd5
BuildRequires:  autoconf2.5
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  libevent-devel
BuildRequires:  libsasl-devel 
BuildRequires:  cyrus-sasl 
BuildRequires:  sasl-plug-plain 
BuildRequires:  sasl-plug-crammd5
# Required by test suite
BuildRequires:  sasl-plug-sasldb
BuildRequires:  libxslt-proc
BuildRequires:  perl-devel

%description
memcached is a flexible memory object caching daemon designed to alleviate
database load in dynamic web applications by storing objects in memory. It's
based on libevent to scale to any size needed, and is  specifically optimized
to avoid swapping and always use non-blocking I/O.

%package        devel
Summary:        Files needed for development using memcached protocol
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description    devel
Install memcached-devel if you are developing C/C++ applications that require
access to the memcached binary include files.

%prep
%setup -q
%apply_patches

%build
%serverbuild

%configure2_5x
#--enable-sasl
%make
make docs

%if %_with_test
%check
export PATH="$PATH:/sbin:/usr/sbin"
# whitespace tests fail locally on fedpkg systems now that they use git
rm -f t/whitespace.t

# Parts of the test suite only succeed as non-root.
if [ `id -u` -ne 0 ]; then
  # remove failing test that doesn't work in
  # build systems
  rm -f t/daemonize.t
fi
make test
%endif

%install
%makeinstall_std

install -m644 %{SOURCE1} -D %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -m644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -m644 %{SOURCE3} -D %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -m755 scripts/%{name}-tool %{buildroot}%{_bindir}/%{name}-tool

install -m644 %{SOURCE4} -D %{buildroot}%{_unitdir}/%{name}@.service
install -m644 %{SOURCE5} -D %{buildroot}%{_unitdir}/%{name}.target

%post
%_tmpfilescreate %{name}
%_post_service %{name} %{name}.target

%preun
%_preun_service %{name} %{name}.target

%pre
%_pre_useradd %{name} /dev/null /bin/false

%postun
%_postun_userdel %{name}

%files
%doc AUTHORS* COPYING ChangeLog NEWS 
%doc doc/CONTRIBUTORS doc/protocol.txt doc/readme.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/%{name}-tool
%{_bindir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}*.service
%{_unitdir}/%{name}.target
%{_mandir}/man1/%{name}.1*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h


%changelog
* Wed Nov 16 2016 neoclust <neoclust> 1.4.25-1.mga5
+ Revision: 1067547
- New version 1.4.25
  fix vulnerabilities allowing remote code execution (CVE-2016-8704, CVE-2016-8705, CVE-2016-8706)

* Wed Oct 15 2014 umeabot <umeabot> 1.4.17-3.mga5
+ Revision: 740976
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.17-2.mga5
+ Revision: 682352
- Mageia 5 Mass Rebuild

* Tue Jan 14 2014 oden <oden> 1.4.17-1.mga4
+ Revision: 566539
- 1.4.17 (fixes CVE-2013-0179, CVE-2013-7239, CVE-2013-7290, CVE-2013-7291)

* Mon Dec 30 2013 luigiwalser <luigiwalser> 1.4.15-6.mga4
+ Revision: 563337
- add upstream patch to fix CVE-2013-7239

* Fri Nov 22 2013 oden <oden> 1.4.15-3.mga4
+ Revision: 552293
- P0: security fix for CVE-2011-4971

* Mon Oct 21 2013 umeabot <umeabot> 1.4.15-2.mga4
+ Revision: 540662
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 dlucio <dlucio> 1.4.15-1.mga4
+ Revision: 494128
- filelist fix
- 1.4.15

* Sun Mar 24 2013 colin <colin> 1.4.13-7.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sat Jan 12 2013 umeabot <umeabot> 1.4.13-6.mga3
+ Revision: 359938
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.4.13-5.mga3
+ Revision: 321726
- Use new macros for tmpfiles
- No need to pass in the templated unit name to the post_service helper

* Mon Aug 20 2012 colin <colin> 1.4.13-4.mga3
+ Revision: 282506
- Switch the .target to PartOf= rather than BindTo= now that we have systemd >= 188

* Mon Jul 23 2012 colin <colin> 1.4.13-3.mga3
+ Revision: 273742
- Add tmpfiles.d config to create PID dir
- Drop sysvinit script

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-2.mga3
+ Revision: 257589
- Bump release
- Convert tabs to spaces (rpmlint)
- Got rid of trailing space

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-1.mga3
+ Revision: 257582
- New version - 1.4.13

  + colin <colin>
    - Implement a systemd target to easily control all memcache instances

* Sat Apr 28 2012 tmb <tmb> 1.4.11-3.mga2
+ Revision: 233790
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Apr 02 2012 colin <colin> 1.4.11-2.mga2
+ Revision: 227942
- Bring sysconfig file and initscript into sync
- Add systemd (template) unit

* Tue Jan 31 2012 dmorgan <dmorgan> 1.4.11-1.mga2
+ Revision: 203721
- New version 1.4.11
  Disable sasl support ( need to fix build )
  Disable tests ( need to be fixed )

* Mon Jan 24 2011 erwan <erwan> 1.4.5-6.mga1
+ Revision: 37960
- imported package memcached


* Sun Jan 02 2011 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-6mdv2011.0
+ Revision: 627635
- don't force the usage of automake1.7

* Wed Dec 22 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-5mdv2011.0
+ Revision: 623867
- rebuilt against libevent 2.x

* Wed Nov 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-4mdv2011.0
+ Revision: 598316
- fix build (fedora)

* Mon May 03 2010 Colin Guthrie <cguthrie@mandriva.org> 1.4.5-3mdv2010.1
+ Revision: 541718
- Fix typo and program name in status output
- Rewrite init script to support multiple instances.
- Fix the case where you want memcached to listen on all network interfaces

* Thu Apr 22 2010 Colin Guthrie <cguthrie@mandriva.org> 1.4.5-1mdv2010.1
+ Revision: 537935
- New version: 1.4.5
- Disable test profiling as it seems to break build.
- Remove check for daemon binary in init script. It's part of the same package.

* Tue Feb 23 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.4.4-2mdv2010.1
+ Revision: 509869
- add missing buildrequires required for test suite and enable it as well
- fix incorrect group for devel package
- fix > 80 character width description for -devel package
- rewrite init script
- don't enable unix sockets / disable networking by default anymore
- cleaned up spec

* Wed Dec 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-1mdv2010.1
+ Revision: 475222
- 1.4.4

* Sun Nov 08 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.3-1mdv2010.1
+ Revision: 462976
- 1.4.3
- new url
- simplify the initscript and config file
- fix deps

* Sun Oct 25 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.2-1mdv2010.0
+ Revision: 459200
- 1.4.2

* Sat Sep 19 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.1-1mdv2010.0
+ Revision: 444621
- 1.4.1
- drop repcached. maybe reintroduce it later

* Sun Jun 07 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.8-1mdv2010.0
+ Revision: 383709
- 1.2.8
- repcached-2.2-1.2.8
- drop upstream patches
- temporary disable "make test"
- fix deps

* Mon May 04 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-5mdv2010.0
+ Revision: 371632
- P1: security fix for CVE-2009-1255

* Mon Jan 05 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-4mdv2009.1
+ Revision: 325075
- repcached-2.2

* Wed Dec 17 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-3mdv2009.1
+ Revision: 315234
- rebuild

* Wed Aug 27 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-2mdv2009.0
+ Revision: 276664
- repcached-2.1

* Sun Aug 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-1mdv2009.0
+ Revision: 270210
- 1.2.6
- rediffed the latest repcached-2.0 patch

* Sat Jun 28 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-3mdv2009.0
+ Revision: 229679
- hardcode %%{_localstatedir}

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Wed May 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-2mdv2009.0
+ Revision: 207045
- rebuilt against libevent-1.4.4

* Thu Apr 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-1mdv2009.0
+ Revision: 192539
- 1.2.5
- rediffed and adjusted repcached-1.2-1.2.4.patch slightly
- fix lib64 stuff
- use --enable-64bit on x86_64

* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.4-1mdv2008.1
+ Revision: 173417
- 1.2.4
- new repcached patch (1.1)
- drop upstream implemented patches

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Nov 16 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-2mdv2008.1
+ Revision: 109084
- added upstream socket permission fix (P0)
- added replication support (P1)
- added pid file generation fix from fedora (P2)
- major initscript and config rework

* Wed Aug 22 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-1mdv2008.0
+ Revision: 68952
- 1.2.3

* Mon Jul 16 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.2-2mdv2008.0
+ Revision: 52533
- use the %%serverbuild macro

* Sat May 19 2007 David Walluck <walluck@mandriva.org> 1.2.2-1mdv2008.0
+ Revision: 28446
- 1.2.2
- LSB-complaint and MDV-complaint initscript

* Fri Apr 27 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.1-1mdv2008.0
+ Revision: 18625
- 1.2.1


* Tue Dec 19 2006 Oden Eriksson <oeriksson@mandriva.com> 1.2.0-3mdv2007.0
+ Revision: 100284
- release bump due to #27632
- fix deps (libnet1.1.2-devel)
- fix deps (perl-devel)
- rebuild
- 1.2.0
- fix deps
- bunzip sources
- Import memcached

* Sat Jun 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-4mdv2007.0
- fix deps

* Mon Apr 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-3mdk
* Fri Mar 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-2mdk
- rebuilt against libnet1.1.2

* Sat Nov 26 2005 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-1mdk
- 1.1.12
- fix deps

* Wed May 11 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.1.11-2mdk
- add prereq on rpm-helper
- rebuild for new libevent

* Sun Jan 23 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 1.1.11-1mdk
- initial Mandrakelinux package

